# encoding: utf-8

"""
Some utility functions for pybehave

Translate a sentence into a camel-name

    >>> make_camel_name('User can lOg IN')
    'UserCanLogIn'

Translate a sentence into a python-name

    >>> make_python_name('User can lOg IN')
    'user_can_log_in'
    
Translate a camel-name into a phrase

    >>> make_phrase('UserCanLogIn')
    'User can log in'
    
"""

import string

__author__ = 'Raphael.Marvie@lifl.fr'
__date__ = '2007-03-20'


def make_camel_name(sentence):
    """Returns a CamelName from the plain text sentence."""
    return _make_name(sentence, '', str.capitalize)


def make_python_name(sentence):
    """Returns a python_name from the plain text sentence."""
    return _make_name(sentence, '_', str.lower)


def _make_name(sentence, separator, word_case):
    return separator.join([word_case(x) for x in sentence.split()])


def make_phrase(camel_name):
    """Return a phrase from a CamelName"""
    result = list()
    for c in camel_name:
        if c in string.uppercase:
            result.append(' ')
        result.append(c)
    return ''.join(result).strip().capitalize()

if __name__ == '__main__':
    import doctest
    doctest.testmod()

# eof
