#!/usr/bin/env python
# encoding: utf-8

"""
Script for the production of behavioral test skeletons from textual 
specification of stories.
"""


import sys
import getopt

import pybehave.parse
import pybehave.generate


__author__ = 'Raphael.Marvie@lifl.fr'
__date__ = '2007-03-21'


help_message = ''' 
Produces a skeleton of behavioral tests from a textual  description of stories.

 spec2behave.py [option] file.story

 -h --help     This message
 -s --skel     Generate skeleton of (given, event, outcome) to be completed.
'''


class Usage(Exception):
    def __init__(self, msg):
        self.msg = msg


def process(filename, with_skeletons):
    """docstring for process"""
    parse = pybehave.parse.StoryParser()
    fspec = open(filename)
    spec = parse(fspec.read())
    fspec.close()
    for story in spec.stories:
        pybehave.generate.generate_bdd(story, with_skeletons)


def main(argv=None):
    if argv is None:
        argv = sys.argv
    with_skeleton = False
    expected = 2
    try:
        try:
            opts, args = getopt.getopt(argv[1:], "ho:v", ["help", "skel"])
        except getopt.error, msg:
            raise Usage(msg)
    
        # option processing
        for option, value in opts:
            if option in ("-h", "--help"):
                raise Usage(help_message)
            if option in ("-s", "--skel"):
                with_skeleton = True
                expected += 1
    
        if len(argv) < expected:
            raise Usage(help_message)
        else:
            process(argv[-1], with_skeleton)
    
    except Usage, err:
        print >> sys.stderr, sys.argv[0].split("/")[-1] + ": " + str(err.msg)
        print >> sys.stderr, "\t for help use --help"
        return 2


if __name__ == "__main__":
    sys.exit(main())

# eof
